use Perlmazing qw(_isa_ref);

sub main ($) {
	_isa_ref('REF', $_[0]);
}

